@@ -27,6 +27,7 @@
 */
 
 #include <mpd/playlist.h>
+#include <mpd/position.h>
 #include <mpd/send.h>
 #include <mpd/response.h>
 #include "isend.h"
@@ -88,6 +89,22 @@ mpd_run_playlist_add(struct mpd_connection *connection,
 		mpd_response_finish(connection);
 }
 
+bool
+mpd_send_playlist_add_to(struct mpd_connection *connection, const char *name,
+		      const char *path, unsigned to)
+{
+	return mpd_send_s_s_u_command(connection, "playlistadd", name, path, to);
+}
+
+bool
+mpd_run_playlist_add_to(struct mpd_connection *connection,
+		     const char *name, const char *path, unsigned to)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_playlist_add_to(connection, name, path, to) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_playlist_move(struct mpd_connection *connection, const char *name,
 		       unsigned from, unsigned to)
@@ -130,6 +147,23 @@ mpd_run_playlist_delete(struct mpd_connection *connection,
 		mpd_response_finish(connection);
 }
 
+bool
+mpd_send_playlist_delete_range(struct mpd_connection *connection, const char *name,
+			 unsigned start, unsigned end)
+{
+	return mpd_send_s_range_command(connection, "playlistdelete", name,
+					start, end);
+}
+
+bool
+mpd_run_playlist_delete_range(struct mpd_connection *connection,
+			const char *name, unsigned start, unsigned end)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_playlist_delete_range(connection, name, start, end) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_save(struct mpd_connection *connection, const char *name)
 {
@@ -175,6 +209,27 @@ mpd_run_load_range(struct mpd_connection *connection, const char *name,
 		mpd_response_finish(connection);
 }
 
+bool
+mpd_send_load_range_to(struct mpd_connection *connection, const char *name,
+		    unsigned start, unsigned end, unsigned to, enum mpd_position_whence whence)
+{
+	const char *whence_s = mpd_position_whence_char(whence);
+	char to_str[64] = "";
+	snprintf(to_str, 64, "%s%u", whence_s, to);
+
+	return mpd_send_s_range_to_command(connection, "load", name,
+					start, end, to_str);
+}
+
+bool
+mpd_run_load_range_to(struct mpd_connection *connection, const char *name,
+		   unsigned start, unsigned end, unsigned to, enum mpd_position_whence whence)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_load_range_to(connection, name, start, end, to, whence) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_rename(struct mpd_connection *connection,
 		const char *from, const char *to)
