@@ -57,6 +57,10 @@ bool
 mpd_send_float_command(struct mpd_connection *connection, const char *command,
 		       float arg);
 
+bool
+mpd_send_u_command(struct mpd_connection *connection, const char *command,
+		     unsigned arg1);
+
 bool
 mpd_send_u_f_command(struct mpd_connection *connection, const char *command,
 		     unsigned arg1, float arg2);
@@ -65,6 +69,10 @@ bool
 mpd_send_u_s_command(struct mpd_connection *connection, const char *command,
 		     unsigned arg1, const char *arg2);
 
+bool
+mpd_send_s_s_command(struct mpd_connection *connection, const char *command,
+		       const char *arg1, const char *arg2);
+
 bool
 mpd_send_u_s_s_command(struct mpd_connection *connection, const char *command,
 		       unsigned arg1, const char *arg2, const char *arg3);
@@ -73,6 +81,10 @@ bool
 mpd_send_s_u_command(struct mpd_connection *connection, const char *command,
 		     const char *arg1, unsigned arg2);
 
+bool
+mpd_send_s_s_u_command(struct mpd_connection *connection, const char *command,
+		     const char *arg1, const char *arg2, unsigned arg3);
+
 bool
 mpd_send_range_command(struct mpd_connection *connection, const char *command,
 		       unsigned arg1, unsigned arg2);
@@ -93,6 +105,15 @@ mpd_send_i_range_command(struct mpd_connection *connection,
 			 const char *command, int arg1,
 			 unsigned start, unsigned end);
 
+/**
+ * Send command with one integer argument followed by a range argument
+ * and a to parameter.
+ */
+bool
+mpd_send_s_range_to_command(struct mpd_connection *connection,
+			 const char *command, const char *arg1,
+			 unsigned start, unsigned end, char *to);
+
 bool
 mpd_send_u_range_command(struct mpd_connection *connection,
 			 const char *command, unsigned arg1,
