@@ -356,6 +356,23 @@ mpd_search_add_window(struct mpd_connection *connection,
 	return true;
 }
 
+bool
+mpd_search_add_position(struct mpd_connection *connection,
+			unsigned position, enum mpd_position_whence whence)
+{
+	assert(connection != NULL);
+
+	const size_t size = 64;
+	char *dest = mpd_search_prepare_append(connection, size);
+	if (dest == NULL)
+		return false;
+
+	const char *whence_s = mpd_position_whence_char(whence);
+
+	snprintf(dest, size, " position %s%u", whence_s, position);
+	return true;
+}
+
 bool
 mpd_search_commit(struct mpd_connection *connection)
 {
